distribution_guess: Guesses whether the distribution is normal, uniform, or...

View source: R/distribution_guess.R

distribution_guessR Documentation

Guesses whether the distribution is normal, uniform, or exponential

Description

Uses various metrics to evaluate the type of distribution of a vector of numeric variables, and returns the name of the distribution.

Usage

distribution_guess(vec)

Arguments

vec

A vector of doubles or integers

Value

A string countining the name of the predicted distribution or "unknown" if the distribution was unable to be determined.


harrison-ridland/basic_distributions documentation built on March 6, 2024, 8:15 p.m.