graph_it: Graphs a dataset and its predicted distribution

View source: R/graph_it.R

graph_itR Documentation

Graphs a dataset and its predicted distribution

Description

Predicts the distribution of of a set of numbers and graphs the histogram of the data as well as a line showing the predicted values of the variable.

Usage

graph_it(vec)

Arguments

vec

A vector of doubles or integers

Value

A string containing the words in grammatical order.


harrison-ridland/basic_distributions documentation built on March 6, 2024, 8:15 p.m.