sum_stat: Gives summary statistics of a vector.

View source: R/sum_stat.R

sum_statR Documentation

Gives summary statistics of a vector.

Description

Gives the summary statistics of a vector in a usable form, so that the values can be easily accessed.

Usage

sum_stat(vec, confidence, guess = 0)

Arguments

vec

An vecotr of integers or doubles

confidence

A number between 0 and 1

guess

A double

Value

A data frame that lists mean, stanadrad deviation, lower bound, upper bound, and whether or not the guess is within the bounds


harrison-ridland/basic_distributions documentation built on March 6, 2024, 8:15 p.m.