View source: R/distribution_guess.R
| distribution_guess | R Documentation |
Uses various metrics to evaluate the type of distribution of a vector of numeric variables, and returns the name of the distribution.
distribution_guess(vec)
vec |
A vector of doubles or integers
A string countining the name of the predicted distribution or "unknown" if the distribution was unable to be determined.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.