| graph_it | R Documentation |
Predicts the distribution of of a set of numbers and graphs the histogram of the data as well as a line showing the predicted values of the variable.
graph_it(vec)
vec |
A vector of doubles or integers |
A string containing the words in grammatical order.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.