| sum_stat | R Documentation |
Gives the summary statistics of a vector in a usable form, so that the values can be easily accessed.
sum_stat(vec, confidence, guess = 0)
vec |
An vecotr of integers or doubles |
confidence |
A number between 0 and 1 |
guess |
A double |
A data frame that lists mean, stanadrad deviation, lower bound, upper bound, and whether or not the guess is within the bounds
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.